package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(F``````````0```````
M`+&8``````!``#@`"@!``!H`&0````8````$`````````$``````````0```
M``````!``````````C`````````",``````````(`````P````0````````"
ME`````````*4`````````I0`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*3`````````I,``
M```````0``````$````&````````J]````````"[T````````+O0````````
M!+@````````$X````````!```````@````8```````"KX````````+O@````
M````N^`````````"``````````(```````````@````$````!`````````)P
M`````````G`````````"<``````````D`````````"0`````````!`````0`
M```$````````I*````````"DH````````*2@`````````"``````````(```
M```````$9'3E4`````0```````"=H````````)V@````````G:``````````
M[`````````#L``````````1D=.51````!@``````````````````````````
M````````````````````````````````````$&1TY5(````$````````J]``
M``````"[T````````+O0````````!#`````````$,``````````!````!```
M`!0````#1TY5`%7R>4T1@)8HTBJY)@PZPAWP!9U_+VQI8B]L9#8T+G-O+C$`
M```````````1````0@````0````(A`1`!0`0$""$`(:`!``"*`@$(`D"`(F"
M"`(`ND$0@(@`````````0@```$4```!(````20```%$```!2````4P``````
M``!5````5@```%<```!8````60```%L``````````!_?Q6XM1][.?)I_:[:;
MQ2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/
MF=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,%0N7.@V;G*E_"@*GX%">&FM)^^"C
M```````````````````````````````````````````#```*````````&-@`
M`````````````V$2`````````````````````````````.02````````````
M`````````````````JT1`````````````````````````````GT2````````
M`````````````````````)82`````````````````````````````5T2````
M`````````````````````````;42`````````````````````````````/H2
M``````````````````````````````$@````````````````````````````
M`702`````````````````````````````K42````````````````````````
M`````9P2`````````````````````````````>,2````````````````````
M`````````2L2`````````````````````````````=P2````````````````
M`````````````1L2`````````````````````````````0T2````````````
M`````````````````=02`````````````````````````````J,2````````
M`````````````````````!`@`````````````````````````````7L2````
M`````````````````````````@H2`````````````````````````````JL1
M`````````````````````````````E@2````````````````````````````
M`"P@`````````````````````````````C@2````````````````````````
M`````$82`````````````````````````````A,2````````````````````
M`````````&,6`````````````````````````````4T2````````````````
M`````````````:X2`````````````````````````````'82````````````
M`````````````````-,2`````````````````````````````(<2````````
M`````````````````````:02`````````````````````````````E\B````
M`````````````````````````I(2`````````````````````````````9<2
M`````````````````````````````+<2````````````````````````````
M`>X2`````````````````````````````@,2````````````````````````
M`````?02`````````````````````````````3\2````````````````````
M`````````.X2`````````````````````````````882````````````````
M`````````````FX2`````````````````````````````BD2````````````
M`````````````````C<2`````````````````````````````<T2````````
M`````````````````````*(2`````````````````````````````>D2````
M`````````````````````````6@2`````````````````````````````.D2
M`````````````````````````````;X2````````````````````````````
M`,81`````````````````````````````<42````````````````````````
M`````H02`````````````````````````````AL2````````````````````
M`````````302`````````````````````````````G42````````````````
M`````````````%02`````````````````````````````C\2````````````
M`````````````````HL2`````````````````````````````E$1````````
M`````````````````````VH2```,````````0=``````````U@```[\2```,
M````````./`````````&G````DP2```,````````']@````````"B````N$2
M```,````````*S``````````!@```O\2```,````````/Y`````````"/```
M`^42```,````````*S@````````"7````Z40```7````````P(@`````````
M`````O(2```,````````+9@`````````-@```Q42```,````````-/@`````
M````@@```W81```.````````71``````````!````Y(2```,````````6=``
M```````!]````YT2```,````````*B``````````.````[H0```7````````
MP+```````````````],2```,````````.```````````Z@```_P2```,````
M````-8``````````>````X40```6````````P````````````````SD2```,
M````````+=`````````!2````\P0```7````````P(@``````````````_(1
M```6````````P(``````````"````XL2```,````````(F``````````````
M`[$2```,````````66``````````;````X<@```6````````P```````````
M`````T\2```,````````-]``````````+@```R,2```,````````*E@`````
M````U````T42```,````````6\@````````!!```!`02```,````````+Q@`
M```````%W`!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?
M8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D
M:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`')M9&ER
M`')E860`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E
M86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L
M:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S
M=')C:'(`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!?7V5R<FYO7VQO
M8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI
M8G!E<FPN<V\N-2XT,`!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D
M:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S
M7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D:64`
M<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR``````````(``0`"``(``0`!``(``0`!
M``(``P`"``(``0`"``$``0`"``(``0`!``(``@`"``$`!``!``(``0`!``(`
M`0`!``$``@`"``(``@`!``(``@`%``$``0`%``(`!0`$``(``0`"``$``@`"
M``$``@`"``4``0`"``$`!@`"``(``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`!0```M<````0``````:6
MD;0````&```$$0```!`-:6D4````!0``!!P````0!I:1LP````0```0F````
M$`EI&7(````#```$,0```!`-:6D2`````@``!#T`````````````N]``````
M````#````````"-0````````N]@`````````#````````",(````````O_@`
M````````#````````!_8````````P`@`````````#````````,`(````````
MP"``````````#````````&`0````````P"@`````````#````````%UL````
M````P#@`````````#````````%X,````````P$``````````#````````%X0
M````````P$@`````````#````````&`$````````P%``````````#```````
M`%UR````````P%@`````````#````````&`,````````P&@`````````#```
M`````%_T````````P'``````````#````````%_Z````````P(``````````
M#````````&`6````````OZ`````$````"@``````````````````OZ@````)
M````"@``````````````````O[`````*````"@``````````````````O[@`
M```5````"@``````````````````O\`````:````"@``````````````````
MO\@````>````.```````````````````O]`````?````"@``````````````
M````O]@````A````"@``````````````````O^`````E````"@``````````
M````````O^@````X````"@``````````````````O_````!!````"@``````
M````````````O?@````"````"P``````````````````O@`````#````"P``
M````````````````O@@````%````"P``````````````````OA`````&````
M"P``````````````````OA@````'````"P``````````````````OB`````(
M````"P``````````````````OB@````+````"P``````````````````OC``
M```,````"P``````````````````OC@````-````"P``````````````````
MOD`````.````"P``````````````````OD@````/````"P``````````````
M````OE`````0````"P``````````````````OE@````1````"P``````````
M````````OF`````2````"P``````````````````OF@````3````"P``````
M````````````OG`````4````"P``````````````````OG@````6````"P``
M````````````````OH`````7````"P``````````````````OH@````9````
M"P``````````````````OI`````;````"P``````````````````OI@````<
M````"P``````````````````OJ`````=````"P``````````````````OJ@`
M```@````"P``````````````````OK`````B````"P``````````````````
MOK@````C````"P``````````````````OL`````D````"P``````````````
M````OL@````E````"P``````````````````OM`````F````"P``````````
M````````OM@````G````"P``````````````````ON`````H````"P``````
M````````````ON@````I````"P``````````````````OO`````J````"P``
M````````````````OO@````K````"P``````````````````OP`````L````
M"P``````````````````OP@````M````"P``````````````````OQ`````N
M````"P``````````````````OQ@````O````"P``````````````````OR``
M```P````"P``````````````````OR@````Q````"P``````````````````
MOS`````R````"P``````````````````OS@````S````"P``````````````
M````OT`````T````"P``````````````````OT@````U````"P``````````
M````````OU`````V````"P``````````````````OU@````W````"P``````
M````````````OV`````Y````"P``````````````````OV@````Z````"P``
M````````````````OW`````[````"P``````````````````OW@````\````
M"P``````````````````OX`````]````"P``````````````````OX@````^
M````"P``````````````````OY`````_````"P``````````````````OY@`
M``!`````"P``````````ZV_P,``DN00`'Z?[_V#C$/```"3`P```4GK`$```
M4U_C$!````2Y`@`1IX0``PWAXT#Q$``$ZV_PT``$!_0``.,0\#@`),`0``!2
M8=('\#`0".,0$!``!`?Q!P`'``<`P!```%)@XQ`0```$!_$-$.,0$`P`%,#T
M____Y0````#`$```4E3C$!````0'\0T0XQ`0#``4P/3____5````&,`0``!2
M2.,0$```!`?Q#1#C$!`,`!3`]/___\4````PP!```%(\XQ`0```$!_$-$.,0
M$`P`%,#T____M0```$C`$```4C#C$!````0'\0T0XQ`0#``4P/3___^E````
M8,`0``!2).,0$```!`?Q#1#C$!`,`!3`]/___Y4```!XP!```%(8XQ`0```$
M!_$-$.,0$`P`%,#T____A0```)#`$```4@SC$!````0'\0T0XQ`0#``4P/3_
M__]U````J,`0``!2`.,0$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```%'T
MXQ`0```$!_$-$.,0$`P`%,#T____50```-C`$```4>CC$!````0'\0T0XQ`0
M#``4P/3___]%````\,`0``!1W.,0$```!`?Q#1#C$!`,`!3`]/___S4```$(
MP!```%'0XQ`0```$!_$-$.,0$`P`%,#T____)0```2#`$```4<3C$!````0'
M\0T0XQ`0#``4P/3___\5```!.,`0``!1N.,0$```!`?Q#1#C$!`,`!3`]/__
M_P4```%0P!```%&LXQ`0```$!_$-$.,0$`P`%,#T___^]0```6C`$```4:#C
M$!````0'\0T0XQ`0#``4P/3___[E```!@,`0``!1E.,0$```!`?Q#1#C$!`,
M`!3`]/___M4```&8P!```%&(XQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`
M$```47SC$!````0'\0T0XQ`0#``4P/3___ZU```!R,`0``!1<.,0$```!`?Q
M#1#C$!`,`!3`]/___J4```'@P!```%%DXQ`0```$!_$-$.,0$`P`%,#T___^
ME0```?C`$```45CC$!````0'\0T0XQ`0#``4P/3___Z%```"$,`0``!13.,0
M$```!`?Q#1#C$!`,`!3`]/___G4```(HP!```%%`XQ`0```$!_$-$.,0$`P`
M%,#T___^90```D#`$```433C$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0
M``!1*.,0$```!`?Q#1#C$!`,`!3`]/___D4```)PP!```%$<XQ`0```$!_$-
M$.,0$`P`%,#T___^-0```HC`$```41#C$!````0'\0T0XQ`0#``4P/3___XE
M```"H,`0``!1!.,0$```!`?Q#1#C$!`,`!3`]/___A4```*XP!```%#XXQ`0
M```$!_$-$.,0$`P`%,#T___^!0```M#`$```4.SC$!````0'\0T0XQ`0#``4
MP/3___WU```"Z,`0``!0X.,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!``
M`%#4XQ`0```$!_$-$.,0$`P`%,#T___]U0```QC`$```4,CC$!````0'\0T0
MXQ`0#``4P/3___W%```#,,`0``!0O.,0$```!`?Q#1#C$!`,`!3`]/___;4`
M``-(P!```%"PXQ`0```$!_$-$.,0$`P`%,#T___]I0```V#`$```4*3C$!``
M``0'\0T0XQ`0#``4P/3___V5```#>,`0``!0F.,0$```!`?Q#1#C$!`,`!3`
M]/___84```.0P!```%",XQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```
M4(#C$!````0'\0T0XQ`0#``4P/3___UE```#P,`0``!0=.,0$```!`?Q#1#C
M$!`,`!3`]/___54```/8P!```%!HXQ`0```$!_$-$.,0$`P`%,#T___]10``
M`_#`$```4%SC$!````0'\0T0XQ`0#``4P/3___TU```$",`0``!04.,0$```
M!`?Q#1#C$!`,`!3`]/___24```0@P!```%!$XQ`0```$!_$-$.,0$`P`%,#T
M___]%0``!#C`$```4#CC$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!0
M+.,0$```!`?Q#1#C$!`,`!3`]/___/4```1HP!```%`@XQ`0```$!_$-$.,0
M$`P`%,#T___\Y0``!(#`$```4!3C$!````0'\0T0XQ`0#``4P/3___S5```$
MF,`0``!0".,0$```!`?Q#1#C$!`,`!3`]/___,4```2PP!```$_\XQ`0```$
M!_$-$.,0$`P`%,#T___\M0``!,C`$```3_#C$!````0'\0T0XQ`0#``4P/3_
M__RE```$X.MO\#``)./P_SC_<>,P\*@`).-`\*``)%`@\+1!0/"@03#PJ$$@
M\+2R3P"PZ[L`(``-LD\`L=('\,"P*,#E____LL1(``!/Q\0H``!/W+D$`#3`
MY0``'E/$&```3]R5`!``IX0`N,`P``!/Q>-0,```!%B@\+3LF@`$`-BY%`#I
MXV6P```$ZRX``P`-E@-DBJ>J``/`Y?___P;C$/"H``3`,```'[KC`!````3C
M,"`(`"3C`"```"2Y!`!2Q"L``%`"P$```!^KXT!0&``DQ"@``$_MXR!0$``D
M6)#PM*>>``&GQ`#'[.D``P#8[`G__P#803`0"*<H``2G`0`!IW0`A(@```&Y
M%`!"[!(``0#8Z^0``P`-N10`8>-`,```!.-.4```).L6``,`#>-@,`@`!.-A
M4```)*<J``*G.P`0IP;_X^QI``,`V+D4`);K.0`#``VY%`!*IVD``$&C4`#$
M*```3[CE2*````#`,```!#+`Y?___#<2(J>$`%7$*```3ZE!8/"\P.7___W\
MN00`-KD$`)+`(```'BC`Y0```/*Y`@`BIX0`1\0H``!/D\#E___[Z,#E___]
M%=4'\,"P**=T`%NY!``IZV_P^``$!_[`Y?___,?$*P``3WRY`@`BIX0`3L#E
M___]/<`P``!/`N,@,```!.-"L```!)(`20:G]/\UXS`P```$XS!0(``DIR@`
M!4$P$!`9+J=T_W.G]/^2Q"@``$]6P.7___P[I_3_I\!0``!/2N,@4````J>$
M``?`Y0``#]JG]/^PN00`-L`@```=HL#E````E,0K``!/-;D"`"*GA/^AI_3_
M[*=H``2G]/]KP.7___VDIRD``<#E___]+T%`\`CC,/````2G"?_PN8``\*?[
M_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```3K7C("````3`Y?___G\`
M``<'!P<'!\`0``!.\,`@``!.[;D@`!('CL08``!.?[D"`!$'C@?QP!```$[@
MP"```$[=N0D`$NL!``,`"NLQ`#\`#+D(`##K,P`!``JY`@`S!X[$&```3F:Y
M`@`1!X[`(```3L0'\>N_\%@`),"P``!.O>/P_V#_<94`L`"G=``5P!```$Y?
MXQ`0```"IX0`",0H``!.:\#E___\H,#E____M9(!L`#KO_#X``0'_L#T____
MO`<'ZV_P,``DQ!@``$XAX_#_8/]QXW`0```"IX0`5+D$`(*Y!`!CXP`@``"4
MN00`DI4`(`"GA`!+IPX`/:>$``M!D)`!XP"0``"4E0"0`*=T__4;F..@<```
M`J>$`!^Y%`"9N00`M[D$`$FY!``XN00`*L#E___[J!(BIW0`"$$IH`"5/2``
MIX0`#T&PL`CCH+````*G=/_IN00`*NMO\-``!`?^0:F@`;GI<#NY!``JZT,`
M`P`*4$!@`.MO\-``!`?^IZD``*?T_^FGF```I_3_P^NO\%``)./P_LC_<;)/
M`+"Y!`"BZ[L`(``-03#PH+)/`+'2!_$PL"C`Y?___-02(J=T`!\8$E@@\+C`
M*P``\`"G+D``IX0`!\(M``"@`*=T`!*Y!``JISD``L#E___].Q`2IQK__X@0
M`!^G]``$IQ@``+D4`"'5!_$PL"BG=``&ZZ_QB``$!_[`Y?___'0'!^MO\#``
M)./P_L#_<;)/`*#KJ@`@``VR3P"AN0(`8M('\3B@**>$``:5`&``IW0`"]4'
M\3B@**=T`)/K;_%P``0'_L#E___]+[D"`)*GA/_RN00`*<#E___[IKD"`"*G
MA`!D0;`@$Y4N(!.G=``&E0"P`:>$_^^5+B`3IX0`8J<(``"Y!``6N00`.Z=)
M``"G60``LEX`0:<4__ZR7@!3IQ3__KD)`$:Y"0!;&D6G2@`"N10`),#E___Z
M1N.P\*``),!0```;SKD$`+*G2?__ISD``<#E___\QT$P\*BY!``KP.7___L`
MIR[__[D$`"NGA``+6`#PP,`+``#P`*<.0`"GA``IP.7___PNN00`*\#E___\
M:;D$`"G`Y?__^T2Y`@`BIW3_H+D$`"G`Y?__^?NY!``FP.7___HVI_3_>Y4N
ML`&G=/^>E0"P`J>$_X.G]/^8P.7___]7I_3_V<#E___[P@<'!P<'!^MO\#``
M))4],`#C\/](_W%!H#`!IP@``+GB<*.R3P!@N00`&NMF`"``#:>)``"R3P!A
MN00`LD$P\*S2!_"P8"BR7@"!IQ3__KD)`(K`Y?___G:Y`@`BIX0`G:<(``"G
MV0``N00`$K)>`-&G%/_^N0D`TKDA`(VGQ`!ZXW#PK``4Q-@``$R`ZW<``P`-
MXR"P``"4N00`2Y4`L`"G=``-I_0`[D%`0`'C($```)25`$``IX0`!J<N`#VG
M=/_UN0D`2[D4`)1!*)`"N00`A^.`T```",#E___Y@^,@@```)+D"`"*GA``[
MXP"P``"0XS#0```$XU<P```$0@!0`$'@L`$8<+D"``"G=``0I_0`/^,0X```
MD$(0L`%!X.`!&'&Y`@`1IX0`,T)P\*"Y!`"UE3WPH$%04`&G=/_LDCVP`*?9
M``#C3:```)!"3;`!I]L``;D"`$2G=/_WU0?PL&`HIW0`F.MO\.@`!`?^IYD`
M`..)H```D$*)(`"GFP`!N0(`B*=T__>G]/_JN00`M:?T_]?$V```2_CC<-``
M``3C$'````*GA`!PN00`1Z>8```8":>:``%!0$`(XS!````"IW3_^*<*``.Y
M%``PZR,``P`-P%```$Q0XQ!0```2IW0`-\#@``!,2.5,X````<#E___X]KD"
M`!+C$/"@`"2GA/^NN00`-[D4`'GK=P`#``VY!`!'P.7___ECXR#PH``$XR#0
M```D4)#PK.-0\*``!*>:``&Y%`"9ZSD``P`-0>-0`.5(X````*?T_R.Y!``R
MN00`)\#E___YL^,@\*``).,@T```)+D"`"*GA/]XN10`2>MT``,`#:?T_]>G
MF0``I_3_(Z<I`!"GF```I_3_H\#E___Z=0<'!P?K?_`X`"3C\/]8_G'C$/"@
M`7&Y!`"BN00`D[)/`+!!@/"@Z[L`(``-N00`.+)/`+&G20__P"```!H7T@<0
M`+`HP.7___DP$B*GQ``1[`+__P#8&!*Y%``@03+PH)4`,`"G=``B$@"G=``>
MP%```$M3X^!0```$N00`2;D$`#KC+K````3`Y?__^,[C0/"@`7'5!T``L"BG
M=``JZW_PX`$$!_X8$+D4`'&G.0`ON00`1[D$`"C`Y?__^0:Y`@`BIX3_UKD$
M`#JY!`!7P*```$LCN00`2..0H```!.,IL```!,#E___YH*?T_]+`Y?__^?O`
M$```2Q#`4```.>W$2```2P[K;_`P`"3`,```&;7CL!````3C\/]8_W&R3P"@
MZZH`(``-LD\`H>,KH```!,!@```;`L#E___ZIKD$`%;E2/"@``#`0```"LKC
M*Z````3`,```&9_`Y?__^07K;_#8``0'_@<'!P>R3P`@P!```$K2ZS(`(``-
MXT`0```$LD\`,<!0```YI^,D,```!,1(``!*Q<`P```9;\#T___Z<^MO\#``
M)./P_TC]<>,0\+`"<;)/`)#KF0`@``VR3P"1T@<0`)`H0;#PKN.`\*\!<<#E
M___Y2,`````9;>,`\*``)+D$`&+`4```&5^G21`!ISD``;D$`"O`Y?__^C2G
M21``N00`*[D$`#C`Y?__^$L2(J=$`"JY!`!BIRH``;D4`"+`Y?__]X^Y`@"B
MIX0`#[D4`+:Y!``XN00`2\#E___Z8D$[H`"2`#``XT#PL`)QU0=``)`HIW0`
M#+D$`"KK;_#H`@0'_J>I``"G]/_PP.7___DY!P<'!\#T____E`<'ZV_P,``D
MX_#^L/YQXQ#Q2`%QN00`LKD$`).R3P!P03#PM.MW`"``#<`@```9![)/`''2
M!Q``<"C`Y?__^_2G.0`ON00`HKD$`"O`Y?__^1NY`@`BIX0`&,`@```8]+D$
M`#O`Y?___4.Y!``KXQ#Q2`%QU0<0`'`HIW0`[^MO\8`!!`?^N00`*<#E___X
M',`P```8X,#E___W9KD"`&*GA/_=09#Q2$&`\+B5`&``IX0`IKD"`*JGA``.
MIP@``+D$`#:Y!``JLET`,J<4__ZGA`"&IP@``*=)``"Y!`!6LEX`1:<4__ZY
MZ6`DXQ!/__]QN2$`8:>D`#>YZ6`!IP$``:>$``^5+Q``IW0`(9(`$`#C$!__
M_W&Y(`!AIX0`&.O@``$`#)4O$`"G=``1D@`0`.LO'___5:=T``KK`!___U+C
M$!_^_W&GY__OIP@``*<I``"Y!``VLEX`(Z<4__ZY"0`FIP@``*=)``"Y!`!;
MLEX`1:<4__ZY"0!+000@`<(.```/_Z<D_VK`X```&&3CL/"H`"3CX/"@`"3`
M4```&-*G21``ISD``;D$`"G`Y?__^1JY!``XN00`*<#E___W4Q(BIW0`#%A@
M\-#`:P``\`#";0``@`"GA``GP#```!@ZIRD``,#E___VOKD"`&*GA/\UE0!@
M`*=T_UZY`@"JIX0`!I4NH`"GA``)IRD``<!@```8$Z?T_Z>5`*`!IX3_WZ?T
M__6G.0`!N00`*<#E___XRA(BIW3_T[D$`#G`(```&`+`Y?___%.Y!``IP.7_
M__<ZI_3_#<#E___X!0<'!P?KO_!8`"2G.0`ON00`LN/P_V#_<<#E___XED$0
M(`&Y`@`BN00`*^N_\/@`!+GB<"'`]/__]Q@'!^N?\$@`)./P_UC^<;)/`*#C
M$/"@`7'KJ@`@``VR3P"AT@<0`*`HN0(`,J>$`&25`#``IX0`8*<(``"GF0``
MN00`([)>`)*G%/_^N0D`D^Q)``$`V<).```0`*<D`'!!L/"@N00`*\#E___X
MP>-)O___<;DA`$NGQ``>N>FP!*=!``&G=`!)ZS```0`,E2]``*=T`!&2`$``
MZR]/__]5IW0`"NL`3___4N-`3_[_<:<W_^^G.0`ON00`*\#E___X)[D"`%*G
MA``7N2$`6Z<D`#.Y!``KP.7___:JX^#PH`%QU0?@`*`HIW0`+NN?\/`!!`?^
MXQ#PH`%QU0<0`*`HIW0`(L`@```73>N?\/`!!,#T___VC94O0`"G=/_-D@!`
M`.-`3___<;D@`$NG=/^NI_3_PI(`4`"G]/_-IRD``*?T_\[`Y?__]T/KK_!0
M`"3C\/]0_W&R3P"@0;#PI.NJ`"``#;)/`*'2!_"HH"BY!``[P"```!<EP.7_
M__H)N0(`(J>$`##C0/"D`!3$*```2"/K%``#``WC$"````CC4!`(``3C4!``
M`"2Y`@!5IX3_X.,`$!``!.,`$`@`)$$0$`BY`@``IW3_]KD$`#O`(```%O?`
MY?__^=NY`@`BIW3_U+D$`#O`(```%O#`Y?__^<^Y`@`BIX0`,.,0\*0`%,18
M``!'Z>OA``,`#>/@4```".,`X`@`!.,`X```)+D"``"GA/_@XS#@$``$XS#@
M"``D0>#@"+D"`#.G=/_VN00`.\`@```6PL#E___YH;D"`"*G=/_4N00`.\`@
M```6NL#E___YE;D"`"*GA``PXU#PI``4Q.@``$>OZT4``P`-XT#@```(XS!`
M"``$XS!````DN0(`,Z>$_^#C($`0``3C($`(`"1!0$`(N0(`(J=T__:Y!``[
MP"```!:,P.7___EGN0(`(J=T_]2Y!``[P"```!:%P.7___E;N0(`(J>$`##C
M,/"D`!3$*```1W7K$P`#``WC$"````CC0!`(``3C0!```"2Y`@!$IX3_X.,`
M$!``!.,`$`@`)$$0$`BY`@``IW3_]KD$`#O`(```%E?`Y?__^2VY`@`BIW3_
MU+D$`#O`(```%D_`Y?__^2&Y`@`BIX0`,.,0\*0`%,1(``!'.^M1``,`#>-0
M0```".,`4`@`!.,`4```)+D"``"GA/_@X^!0$``$X^!0"``D05!0"+D"`.ZG
M=/_VN00`.\`@```6(<#E___X\[D"`"*G=/_4N00`.\`@```6'<#E___XY[D"
M`"*GA``PXT#PI``4Q%@``$<!ZS0``P`-XS!0```(X^`P"``$X^`P```DN0(`
M[J>$_^#C(#`0``3C(#`(`"1!,#`(N0(`(J=T__:Y!``[P"```!7OP.7___BY
MN0(`(J=T_]2Y!``[P"```!6[P.7___BMN0(`(J>$`##CX/"D`!3$*```1L?K
M'@`#``WC$"````CC,!`(``3C,!```"2Y`@`SIX3_X.,`$!``!.,`$`@`)$$0
M$`BY`@``IW3_]KD$`#O`(```%8W`Y?__^'^Y`@`BIW3_U+D$`#O`(```%:_`
MY?__^'.Y`@`BIX0`,.,0\*0`%,0X``!&C>M!``,`#>-`,```".,`0`@`!.,`
M0```)+D"``"GA/_@XU!`$``$XU!`"``D04!`"+D"`%6G=/_VN00`.\`@```5
M@<#E___X1;D"`"*G=/_4N00`.\`@```5>L#E___X.;D"`"*GA``PXS#PI``4
MQ$@``$93Z^,``P`-X^!````(XU#@"``$XU#@```DN0(`5:>$_^#C(.`0``3C
M(.`(`"1!X.`(N0(`(J=T__:Y!``[P"```!5,P.7___@+N0(`(J=T_]2Y!``[
MP"```!5%P.7___?_N0(`(J>$`##C4/"D`!3$Z```1AGK%0`#``WC$.````CC
M(!`(``3C(!```"2Y`@`BIX3_X.,`$!``!.,`$`@`)$$0$`BY`@``IW3_]KD$
M`#O`(```%1?`Y?__]]&Y`@`BIW3_U+D$`#O`(```%-C`Y?__]\6Y`@`BIX0`
M,.,0\*0`%,0H``!%W^LQ``,`#>,P(```".,`,`@`!.,`,```)+D"``"GA/_@
MXT`P$``$XT`P"``D03`P"+D"`$2G=/_VN00`.\`@```4JL#E___WE[D"`"*G
M=/_4N00`.\`@```4UL#E___WB[D"`#*GA``(P"```!3"P.7___CEN00`.\`@
M```4S<#E___W>;D"`#*GA``(P"```!3,P.7___C3N00`.\`@```4RL#E___W
M9[D"`#*GA``9P"```!1KP.7___C!U0?PJ*`HIW0`(L`P```4QL`@```4?>NO
M\0``!,#T___XL+D$`#O`(```%*_`Y?__]T2Y`@`RIX3_Y<`@```4=L#E___X
MGJ?T_]W`Y?__]%4'!P<'Z[_P6``DP"```!1FX_#_4/]QLD\`L$$P\*3KNP`@
M``VR3P"QT@?PJ+`HP.7___<;N0(`(J>$`"!#$"``&`'`!P```#"YA``PN0,`
M0Z=8``#KY``_``RG$0#_N?*`Y;D4`"[5!_"HL"BG=``*Z[_Q"``$!_ZGZ```
MI_3_\\#E___T$@<'!P<'!V``\(!@(/"(8$#PD&!@\)BR3P`0ZS_P&``DX_#_
M./]QZS$`(``-N00`0K)/`#%!`/%H02#PR,1H``!%'4%0\*#2!_#`,"CC(/"X
M`"3C`/"P`"3E2/"@``'E2/"H``#C(&````2G.0`!P.7___.HIRD`_\#E___S
M8Z<Y``"G20`"ZX_P0``DX_#_4.]QXQ#PJ!!QN00`@K)/`*#KJ@`@``VR3P"A
MT@<0`*`H0;#PH,#E___R!<`Q__\``.R2__\`V>P),(``5>P@__\`V;F!`".G
M*P`!N0(``+GB0`*Y"0"0N0(`F:=$`).G20``N00`.;D$`"C`Y?__\>*G+___
MIX0`H,!!``$`"+D$`#NY!``HP.7___/DIR[__Z>$`(RY%`!"PDX````'I\0`
M:>,4O_C_<;DA`!NG1`!B[%$^OP!5Q.@``$2HX^`0```@IX0`;>,0'___<;DA
M`!NG1`!0N0(`5:>$`":G7P`!IX0`%J=?``*GA``*X^`0```@IX0`5>,0'___
M<>/@$```(*>$`$WC$!___W'CX!```""GA`!%XQ`?__]QN2$`&Z=$`"CCX!``
M`""GA``YXR`?__]QN00`$N/@(```(*>$`"_C$"___W'CX!```""GA``GXQ`O
M_O]QX^`O_O\@IX0`'^,0+_W_<;DA`!NGI/_<PI0``0``PIS__P``IW3_<:<I
M___C@/"H$''5!X``H"BG=``8ZX_P\!`$!_ZYZ;`AN0@`*:?T__#`(```$TS`
MY?___N3`(```$S_`Y?___M[`Y?__\N?K[_!P`"3C\/]@_W'`Y?__\,[`Y?__
M\*NY`@`BIX0`!>,@(```!.OO\1``!`?^!P?K;_`P`"3C\/]`_W&R3P"@N00`
M8NNJ`"``#4$P\+2R3P"AP"```!,:T@?PN*`HP.7___65N0(`LJ>$``:5`+``
MIW0`$M4'\+B@**=T`$VY!``VP"```!,"ZV_P\``$P/3___;AIP@``+D$`#NY
M!``6ITD``*<I``"R7@!#IQ3__K)>`"&G%/_^N0D`2[D)`"9!(D`"P.7___"R
MP````!)VX[#PJ``DXP#PH``DN00`LL!0```2XZ=)__^G.0`!P.7___,MU0?P
MN*`HIW0`#;D$`#O`(```$L+K;_#P``3`]/__]J'`Y?__\EH'!P<'!P?K;_`P
M`"3C\/X0_W&R3P!PZW<`(``-LD\`<<`0``!#@[D$`-)!H/#$P"```!(KN00`
M.M('\>AP*-(/\,@0$-('\-@0(-(O\/@0*-(/\.`06-('\/`0:,#E___U";D"
M`+*GA``&E0"P`*=T`FS`Y?__\`[`Y?__[^NY`@`BIX0!%^.P(````J>$`1*G
M"```ISD``+D$`$NR7@`TIQ3__KD)`#OK(P`!``VG*P`!P.7___`NE0"P`.-@
ML```E+D$`)*Y!`""IX0`&[D6`&:Y!``IP%```!)7ITG__Z<Y``'`Y?__\J5!
ML+`!09"0`N-@L```E)4`L`"G=/_I09#Q`,`@```2#Z?T``FGFP`(XR"?^/\"
MIX0`'KD$`#K`Y?__]*>Y`@"RIX3_\I4`L`"GA/_NP.7___4$$B*GA/_HN00`
M*\#E___PY+D"`&*G=``<09#PR.-@D````J>$`!65`&``IX0`H;D$`";`Y?__
M].@2(J=T`(RGFP`(XV"0```"IW3_[Z<(``"Y!`!8N00`)J<Y``"G20``LEX`
M,J<4__ZR7@!%IQ3__KD)`#:Y"0!(&C2G.@0$N10`L[D$`"O`Y?__[Z;`````
M$>;C@/"P`"3C`/"H`"2Y!`"2P%```!'6ITG__Z<Y``'`@```$5GC@/"@`"3`
MY?__\ANG.0'`N00`*<#E___Q!*<N__^G=``+P.7___#-6&`@`*=N`!&G=`%X
M03#Q*+D$`"G`Y?__\7`8@A(BIW0`"UC@\4#`ZP``\`"G[D``IX0`>L2H``!"
M7+D$`&GC4-````3`0```$;SC(*````2G.0`!P.7___%`I[D``-4'\>AP**=T
M`@FY!``KZV_R(``$!_ZGFP`(N00`)L#E___P/+D"`&*GA/]<I_3_<J=I``"G
M]/]N08#PX.,@@````J>$`!:Y!``ZP.7___/6N0(`4J>$``:5`%``IW0`&:>+
M``CC((````*G=/_NIRD`#<"P```12<#E___O#Z=H`%.Y!`"2N00`@J?T_N:G
MBP`(P.7___`"N0(`LJ>$_]"G"```I^D``+D$`!NR7@#AIQ3__KD)`.OK+@`!
M``VG*P`!I_3^O%A@\43`Y?__[J898J=T_X)8$/%`P!L```'_IQX!P*=T_WFY
M!``KP.7__^[5N00`.KD$`++`(```$5S`Y?__\WNY`@`RIX0`\N,@T```!,#E
M___W8;D"`&*GA`#HIP@``*=)``"Y!``VLEX`0Z<4__ZY"0!&ITX``Z?$`!ZY
M%``DP%```!$YX^)O_/]QLET`7J<4__ZG=``0ITX`!*>$`3>G2O_[N10`%$%!
M8`"5+T``IX0!+;D$`#K`(```$'7`Y?__\SFY`@"BIX0`M>,`H```E!(`IX0`
MKZ<.`#"GA`"KP#```!"9P"```!!>P.7___2&N00`:<#E___O_<!````18\`P
M```0+^-`\+``).,P\*``).,@\*@`),!0```1`+D$`"NG2?__ISD``<#E___P
MXJ?T`#+`Y?__[YU8("``IRX`$:=T`#2GB@`!P*```!`*P.7__^_/P%```!$U
MN10`".-0\+@`).,@\*@`)..@\*``)+D$`&GC`/"P`"2Y!``KP%```!#3ITG_
M_Z<Y``'`Y?__\+"G.0'`N00`*\#E___OF:<N__^GA/_'N00`*<#E___P8+D$
M`#O`(```#\;`Y?__]!RY!``KP.7___T'I_3^M;D4`!;$.```0/CC$/"@`"2Y
M!`!IXU#0```$P$```!`WXR`P```$ISD``<#E___OV:?T_IG`Y?___.C5!_'H
M<"BG=`"?N00`*^MO\B``!,#T___NU^-@T```!*?T_Q>Y!``FISD``,#E___P
M*[D$`-(2(J>$_TW`Y?__^\.Y`@!BIT3_1J=)``#C,&_V_W&Y!``MP.7__^W5
MITD`!D$P\;FY!``MP.7__^_<IR\`!J=T`&O`$```+W+5!1``\;FG=/\GXS!O
MSO]QITD``+D$`"W`Y?__[;:Y!``MITD`*$'0\;^Y!``]P.7__^^[IR\`**=T
M`$K`X```$'W`8```#TF2`/'GXV#PH``DX^#PL``DX]#PJ``DN00`:<!0```0
M#J=)__^G.0`!N00`*\#E___O^*?T_U/CT-`(``*GA/[2IP@``*<I``"Y!``]
MLEX`(Z<4__ZY"0`MPBX````#I\3^P>-2W_S_<<#@```/WK)=`.6G%/_^N>*`
M;:?T_K/`Y?__[P_`(```#]/`Y?__^OT'!P<'ZW_P.``DP*```$`9XQ"@```$
MX_#_4/]QLD\`L$&`\*3KNP`@``W`(```#ORR3P"QN00`.-('\*BP*..1L```
M!-(`D+&0L,#E___QP;D"`"*GA``&E3$@`*>$`-3`Y?__]Y;C,*````3CD[``
M``2Y!``IIUD``Z=)``'`,```#ZS`Y?__[52Y`@"2IX0`'N-`D!``!.-PH```
M!.,P0```!.,GL```!,!````/E\#E___M3N-0D!``!.,P4```!)%`,`VG=`"R
MXW"@```$IUD``^,GL```!*=)``'`,```#X#`Y?__[22Y`@"2IX0`&KD$`#C`
M(```#GO`Y?__\6CC$)`0``2Y`@!"XS`0```$IX0`?^,GL```!,#E___M&..@
MH```!*=)``'C>K````3`,```#U>Y!``GP.7__^QHP$````]:N00`,KD$`"?`
MY?__[/[C.K````22`#"QP"````Y!N00`.,#E___Q,<0K```_TKD$`(*Y`@`B
MIX0`+J<Y`<"Y!``HP.7__^WQ[`(``0#8P@\````!I\0`%J<N`!&GA``2N00`
M4L2X```_L+D$`$C`(```#S3C,+````3`Y?__[G75!_"HL"BG=``VZW_PZ``$
M!_[$*```/YG`Y?__^\+$*P``/Y>Y!`""N0(`(J=T_\?`(```#P+`Y?__[E>5
M`"`!IX3_-:?T_RK$Z```/WZY!``CXS#@```$P.7___.&I_3_?N,GL```!,#E
M___MWJ?T_TK`Y?__[>D'!P<'ZY_P2``DX_#_4/]QLD\`H+D$`++KJ@`@``U!
M,/"DLD\`H<`@```-[-('\*B@*,#E___PK;D"`"*GA``4XQ`@``"4$A&GA``.
MIQX`,*>$``JY`@"[IX0`!I4`L`"G=``+U0?PJ*`HIW0`->N?\/@`!`?^N00`
M*\#E___UQ:<Y`"^Y!`"2P.7__^Y"N0(`(D$`(`&Y!``IN>)P(,#E___LQZ=)
M``3`,```#@7`Y?__[$\2(J=T_]?5!_"HH"BG=``*N00`*^N?\/@`!,#T___Q
M#\#E___M?`<'05`@.*<)``3K;_`P`"3C\/S0_W&R3P"@01#PJ.NJ`"``#;)/
M`*'2!_,HH"CC0%````3C,%`(``3KM``@``SCL!```"3K8P`@``SC8!`0`"3`
M2@````#C0!`(`"3`.@````#C,!`8`"1!4%`0IQL`(*<'_][C,/$0``3C@/$8
M``3CL/$@``3CD/"H``3C0/"P``1!8/"XIUD`0+D$`-OCX&````2Y!``>XQ!@
M,`""N8(`$[F"`!GLL2"_(57LL2`^`5;CL&!P`"2Y!``XN00`E+D$`(VG:P`(
MIU<*YN,`(`@`!.,`\*``).-0(!``!./@(!@`!+GGX)6Y@`"0N8(`GN-`(```
M!.MP``(`#.PT(+\E5>QP`"$>5NPT(#H%5NRW(+\`5>-@\+``!+GGL-7":EJ"
M>9FY@`#4N0@`;KF"`-7C$/"H``2YZ&"-PAI:@GF9XQ`@(``(N0@`$[D(`!GL
MD2"_`%7L`3N_)57L"0`Z!5:Y"``(ZS0``@`,[-`[OR55[#0`(1Y6XQ#PN``$
M[(,@OP!5N><P9\(:6H)YF>QP(+\`5;F``&GLUP`Z!5:Y@@!KN0@`%>,`\,``
M!+D(`!;""EJ">9FY"``=N0@`"^NY``(`#.RY`"$>5KF"`#OLD2"_`%7L83N_
M)56YY'`3N00`-NPY`#H%5NQK(+\`5;F"`!CCT/#(``2Y"``0PMI:@GF9N0@`
M$[GH@`WK-P`"``SL@3N_)57L-P`A'E;L<2"_`%7LAP`Z!5:Y@@"SXQ#PT``$
MN8``N<(:6H)YF;F"`+:Y"`"PN>A@`;D(`+CL8R"_`%7KB0`"``SLB0`A'E:Y
M@@`X[)L@OP!5[-L[OR55N>1PL[D$`#WL.0`Z!5:Y@@"VXQ#PV``$N0@`L,(:
M6H)YF;D(`+.YZ&`!ZS<``@`,[&@@OP!5[#<`(1Y6N8(`@^Q[(+\`5>S;.[\E
M5;GDD+BY!`"-[(<`.@56N8(`MN,0\.``!+D(`+#"&EJ">9FY"`"XN>A@`>N)
M``(`#.QC(+\`5>R)`"$>5KF"`#CLFR"_`%7LVSN_)56YY'"SN00`/>PY`#H%
M5KF"`+;C$/#H``2Y"`"PPAI:@GF9N0@`L[GH8`'K-P`"``SL:""_`%7L-P`A
M'E:Y@@"#['L@OP!5[-L[OR55N>20N+D$`(WLAP`Z!5:Y@@"VXQ#P\``$N0@`
ML,(:6H)YF;D(`+BYZ&`!ZXD``@`,[&,@OP!5[(D`(1Y6N8(`..R;(+\`5>S;
M.[\E5;GD<+.Y!``][#D`.@56N8(`MN,0\/@`!+D(`+#"&EJ">9FY"`"SN>A@
M`>LW``(`#.QH(+\`5>PW`"$>5KF"`(/L>R"_`%7LVSN_)56YY)"XN00`C>R'
M`#H%5KF"`+;C$/$```2Y"`"PPAI:@GF9N0@`N+GH8`'KB0`"``SL8R"_`%7L
MB0`A'E:Y@@`X[)L@OP!5[-L[OR55N>1PL[D$`#WL.0`Z!5:Y@@"VXQ#Q"``$
MN0@`L,(:6H)YF;D(`+.YZ&`!ZS<``@`,[&@@OP!5[#<`(1Y6N8(`@^Q[(+\`
M5>S;.[\E5;GDD+BY!`"-[(<`.@56N8(`MN,0\1``!+D(`+#"&EJ">9FY"`"X
MN>A@`>N)``(`#.QC(+\`5>R)`"$>5KF"`#CLFR"_`%7LVSN_)56YY'"SN00`
M/>PY`#H%5KF"`+;C$/$8``2Y"`"PPAI:@GF9N0@`L[GH8`'K-P`"``SL:""_
M`%7L-P`A'E:Y@@"#['L@OP!5[-L[OR55N>20N+D$`(WLAP`Z!5:Y@@"VXQ#Q
M(``$N0@`L,(:6H)YF;D(`+BYZ&`!ZXD``@`,[&,@OP!5[(D`(1Y6N8(`..R;
M(+\`5>S;.[\E5;GD<+.Y!``][#D`.@56N8(`MN,0\2@`!+D(`+#"&EJ">9FY
M"`"SN>A@`>LW``(`#.QH(+\`5>PW`"$>5KF"`(/L>R"_`%7LVSN_)56YY)"X
MN00`C>R'`#H%5KF"`+;C$/$P``2Y"`"PPAI:@GF9N0@`N+GH8`'KB0`"``SL
M8R"_`%7LB0`A'E:Y@@`X[)L@OP!5[-L[OR55XQ#Q.``$N>1PL\(:6H)YF;D$
M`#WL.0`Z!5;LV""_`%6Y@@"VN0@`L+GH8`&Y"`"SZS<``@`,[#<`(1Y6['L[
MOR55N><P:.Q[(#H%5N.`\4``!,"Z`````,**6H)YF;GHT!BY@`!IZXL``@`,
MN8(`;>R+`"$>5KD(`&#K"0`"``RY"`!G[`D`(1Y6[',@OP!5N><`T^R6.[\E
M5;F``-OLEB`Z!5:Y@@#7N0@`T;GG@!"Y"`#9N8(`%NR].[\E5>R](#H%5N,P
M\4@`!..0\5``!,(Z;MGKH<*:;MGKH;D(`#>Y&@"0N1H`,>QV(K\^5;D(`#OL
M=@(A'E;LLSN_)56YYW`8[+,@.@56N8(`'>QM(K\^5;D:`)'L;0(A'E:Y"`";
MX[#Q6``$PKINV>NAN1H`N+GG8(>Y@@"#[`D[OR55N1H`N.P)(#H%5N.`\6``
M!+D(`+#"BF[9ZZ'L&SN_)56Y&@"'[!L@.@56[',BOSY5[',"(1Y6XS#Q:``$
MN>=PUL(Z;MGKH;F"`-FY&@`VN1H`C>QI(K\^5;D(`('L:0(A'E;LF#N_)57L
MF"`Z!5:YYV`7L\$`:;F"`!OCD/%P``2Y&@`QPIINV>NAN1H`E[/-`':Y"``W
M[-,[OR55[-,@.@56['LBOSY5XQ#Q>``$['L"(1Y6PAINV>NAN>=PMKD:`!:Y
M@@"X[&@BOSY5N1H`F^QH`B$>5KD(`)VYYV#7[(D[OR55N8(`T^R)(#H%5KD:
M`!WCL/&```2Y"``8PKINV>NA[(,BOSY5N1H`M^R#`B$>5NP!.[\E5;GG@-;L
M`2`Z!5:Y@@#9XS#QB``$N1H`O<(Z;MGKH;D(`+"Y&@`V[&DBOSY5[&D"(1Y6
M[)L[OR55[)L@.@56N>=@"+/!`'FY@@`!XY#QD``$N1H`,,*:;MGKH;D:`)BS
MS0"'N0@`..S3.[\E5>S3(#H%5NQQ(K\^5>QQ`B$>5N,0\9@`!+GG<`;"&F[9
MZZ&Y@@`+N1H`%KD:`)#L:R*_/E6Y"`"=[&L"(1Y6[+D[OR55N>=@U^RY(#H%
M5KF"`-/C@/&@``2Y&@`=PHINV>NAN0@`&[D:`(?LLR*_/E7L`3N_)57LLP(A
M'E;L`2`Z!5:YY[#6XS#QJ``$N8(`V<(Z;MGKH;D:`(VY&@`VN0@`@.QI(K\^
M5>QI`B$>5NR8.[\E5>R8(#H%5KGG8`NSP0!IN8(``>.0\;``!+D:`##"FF[9
MZZ&Y&@";L\T`MKD(`#OLTSN_)57LTR`Z!5;L<2*_/E7L<0(A'E;C$/&X``2Y
MYW`&PAINV>NAN8(`"+D:`!:Y&@"0[&@BOSY5N0@`G>QH`B$>5NR).[\E5;GG
M8-?LB2`Z!5:Y@@#3X[#QP``$N1H`'<*Z;MGKH;D(`!BY&@"W[(,BOSY5[`$[
MOR55[(,"(1Y6[`$@.@56N>>`UN,P\<@`!+F"`-G".F[9ZZ&Y&@"]N1H`-KD(
M`+#L:2*_/E7L:0(A'E;LFSN_)57LFR`Z!5:YYV`(L\$`>;F"``'CD/'0``2Y
M&@`PPIINV>NAN1H`F+/-`(>Y"``X[-,[OR55[-,@.@56['$BOSY5L\$`#>QQ
M`B$>5NS;(K\^5;GG<`;LVP(A'E:Y@@`+N>?0A^,0\=@`!+F"`(/"&F[9ZZ&Y
M&@`6L\T`8+D:`)"Y&@`8N0@`ENR#(K\^5>RY(+\`5>R#`B$>5NP).[\E5;GG
M@&WL"P`Z!5:Y@@"6N0@`$.,P\>``!,(Z;MGKH;D:`#?L<2"_`%7L$3N_)57L
M%P`Z!5:Y&@`YXY#QZ``$N0@`,<*:CQN\W.L;``(`#+D:`)WL&P`A'E;LT2"_
M`%6YY-`(L\$`*>RS.[\E5>R3(+\`5>-@\?``!+GF$#CLN0`Z!5:Y@``WPFJ/
M&[S<N8$`,+/-``*Y"``PN00`!KD(`#NY&@`(Z[<``@`,XV#Q^``$[+<`(1Y6
MPFJ/&[S<N>30>[F!`!NYZ-#6N8``&;F!`!>Y"``0[(,@OP!5L\$`;>PS.[\E
M5>PX`#H%5KD(`#'K&0`"``SL&0`A'E;LT2"_`%6YY-`+N>80F[F``)BY@0"0
ML\T`!NQS(+\`5;D(`)#L,SN_)57C8/(```3L-P`Z!5;":H\;O-RY!``&N1H`
M"^NX``(`#.RX`"$>5KGDT(NY"`"3N8$`&^PY(+\`5;F``!?LF3N_)56Y@0`8
M[),`.@56N0@`$.N'``(`#+D(`!GLAP`A'E;C8/((``3L>""_`%7":H\;O-RY
MY'`+N>C0UNR1.[\E5;/!`#WLT2"_`%6YYH`;N8``$[F!`!"SS0`#[)T`.@56
MN0@`$.-@\A``!,)JCQN\W+D$``:Y&@`+Z[,``@`,[+,`(1Y6N>:P.+GD<(NY
M"``9N8``/>QA(+\`5>R1.[\E5;F!`#CLE@`Z!5:Y"``PN0@`.>R#(+\`5>L=
M``(`#.P=`"$>5N,`\A@`!+GF$-OLDSN_)57""H\;O-SLF``Z!5:SP0!]L\$`
M*>S1(+\`5;D$`##CD/(@``2Y"``WPIJ/&[S<N>30>[D:`)NSP0!#L\T`LK/-
M``2SP0!IL\T`-^N6``(`#+F``#;LE@`A'E:Y@0`WN>30:;D(`#"Y@0`9N0@`
M.[F``!BSS0`&N8$`%N.P\B@`!+D(`!#"NH\;O-SL<R"_`%6YZ-#;[#,[OR55
M[#<`.@56N0@`,>L8``(`#.P8`"$>5NRQ(+\`5;GDL`GL8R"_`%6SP0`=[(,[
MOR55N>80.;F``#>Y@0`PL\T``>R&`#H%5KD(`##CT/(P``3C`/(X``3"VH\;
MO-S""H\;O-RY&@#9ZY<``@`,[)<`(1Y6N>2P>;F!`!FY@``6N8$`%[D(`!VY
MZ+"PN0@`..R#(+\`5>PS.[\E5>PX`#H%5KD(`#'K%@`"``SL%@`A'E;LT2"_
M`%6YY-`)[',@OP!5L\$`6^QC.[\E5;GF$#FY@``XN8$`,+/-``7L9P`Z!5:Y
M"``PX[#R0``$XP#R2``$PKJ/&[S<P@J/&[S<N1H`N>N8``(`#.R8`"$>5KGD
MT(FY@0`9N8``%[F!`!BY"``;N>C0T+D(`#;L8R"_`%7L,SN_)57L-@`Z!5:Y
M"``QZQ<``@`,[!<`(1Y6[($@OP!5N>2`">RS(+\`5;/!`"WL<SN_)56YYA`Y
MN8``-KF!`#"SS0`"['L`.@56N0@`,./0\E``!.,`\E@`!,+:CQN\W,(*CQN\
MW+D:`-GKE@`"``SLE@`A'E:YY(!IN8$`&;F``!NY@0`6N0@`';GH@("Y"``W
M[',@OP!5[#,[OR55[#<`.@56N0@`,>L;``(`#.P;`"$>5NS1(+\`5;GDT`GL
M8R"_`%7LLSN_)56SP0!(N>80.;F``#>Y@0`PL\T`!.RV`#H%5KD(`##C@/)@
M``3"BH\;O-RY!``(N1H`">N7``(`#.R7`"$>5KGDT'FY@0`9N8``%KF!`!>Y
M"``0N0@`.^.`\F@`!.RS(+\`5<**CQN\W.PS.[\E5>P[`#H%5KD(`#'K%@`"
M``SL%@`A'E;L82"_`%6YY&`)[',@OP!5N>C0V.R#.[\E5;/!`!VYYA`YN8``
M.[F!`#"SS0`![(<`.@56N0@`,./0\G``!+D(`#C"VH\;O-RY!``-N1H`">S3
M(+\`5>N;``(`#.R;`"$>5NRS.[\E5;GD8(FY@0`9[+T`.@56N8``%^,P\G@`
M!+F!`!C".H\;O-RY"``0N>A@`[D(`+'L:SN_)57L:R`Z!5;K%P`"``RSP0!6
M[!<`(1Y6XV#R@``$[($@OP!5N>80>;GD@#FY@`!]PFJ/&[S<N8$`<[D:`&FY
M"`!PL\$`=K/-`)7C8/*(``2YZ)"7PFK*8L'6[`D[OR55ZWT``@`,[`D@.@56
M['T`(1Y6N00`T+GD@#>YZ("&P+H`````N8$`%[/!`"BY@``;L\T`![F!`!/K
MBP`"``RY"``0[(L`(1Y6N0@`';/-`&*YYX#7XS#RD``$N8(`V<(ZRF+!UKD:
M`&VY&@`W[+$[OR55['DBOSY5[+$@.@56['D"(1Y6N0@`MK/!`&/L"SN_)56Y
MYW`X[`L@.@56N8(`,>QA(K\^5>.0\I@`!.QA`B$>5L*:RF+!UKGG8->Y&@"8
MN8(`V[/!``FSS0"6N1H`D[D(`)"SS0``[!D[OR55N1H`#>P9(#H%5KD(`!#L
M,3N_)57L,2`Z!5:SP0`3L\T`T>.`\J``!.,P\J@`!,**RF+!UL(ZRF+!UKD:
M`(>Y&@`V['LBOSY5['L"(1Y6N>=PMNQI(K\^5;F"`+GL:0(A'E:Y&@"+N>=@
M![D(`(VY@@`![)@[OR55N1H`,.R8(#H%5KD(`#GLTSN_)57LTR`Z!5;LD2*_
M/E7CL/*P``3LD0(A'E;"NLIBP=:YYY`&N1H`M[F"``BY&@"PN0@`O>S;.[\E
M5>S;(#H%5N,0\K@`!+/!`'W"&LIBP=;CT/+```2Y&@`6PMK*8L'6[&@BOSY5
MN1H`V>QH`B$>5KGG8(FY@@"#[',BOSY5N1H`&.QS`B$>5K/-`)>YYW"&N0@`
M&;F"`(OL`3N_)57C,/+(``3L`2`Z!5;".LIBP=:Y&@`VN00`;>S;(K\^5;D:
M`&BY"`!@[-L"(1Y6N>?0M[F"`+'C@/+0``3LECN_)56Y&@`[[)8@.@56PHK*
M8L'6N0@`.;D:`(?L`SN_)57L<2*_/E7L`R`Z!5;L<0(A'E;C$/+8``2YYW"]
MPAK*8L'6N8(`MKD:`!WLUB*_/E7LU@(A'E:YY]!GN8(`8[D:`(NY&@`6N0@`
M@.R3(K\^5>P(.[\E5>R3`B$>5NP((#H%5KGGD&VY@@!HN0@`$..P\N``!.P!
M.[\E5<*ZRF+!UNP!(#H%5KD:`+>Y&@"V[&@BOSY5N0@`L.QH`B$>5NR+.[\E
M5;GG8'GLBR`Z!5:Y@@!QL\$`&.,P\N@`!..`\O``!,(ZRF+!UL**RF+!UKD:
M`#VY&@")N1H`-[/-`)'L<2*_/E6Y"``Y['$"(1Y6[`,[OR55N>=PUNP#(#H%
M5KF"`-OC$/+X``2Y&@"-PAK*8L'6N0@`@+D:`!;L:R*_/E7L:P(A'E;LN#N_
M)56YYV`'[+@@.@56N8(``[D:`!"Y"``;[-$[OR55[-$@.@56[+,BOSY5XY#S
M```$[+,"(1Y6PIK*8L'6N>>P!KD:`)>Y@@`(N1H`D+D(`)WLV3N_)57LV2`Z
M!5;C,/,(``2SP0`MPCK*8L'6X]#S$``$N1H`-L+:RF+!UNQH(K\^5;D:`-OL
M:`(A'E:YYV"+L\T`LKF"`(&Y&@`XN0@`.^P#.[\E5>P#(#H%5NR!(K\^5>RY
M(K\^5>R!`B$>5NRY`B$>5KGG@';C$/,8``2Y@@!YPAK*8L'6N1H`U[D:`!:Y
MZ`!MN>>P".R6(+\`5;GG,'"Y!`#;[`8[OR55X]`@(``(N1H`%\#:`````.P)
M`#H%5N/0("``)+D(`!#LTR*_/E7C</"@``3LTP(A'E;K"0`"``RY@@"]N>C@
M[;GG8&O`Z@````#CX"`8`"3L"0`A'E;C,/,@``2Y"``%PCK*8L'6P`H`````
MXP`@$``DN0@`-.Q!(+\`5;D:`#BY"`!T[($[OR55P'H`````XW`@"``D[(0`
M.@56N00`$[D:`!:Y"``8P!H`````XQ`@```DU0?S**`HIW0`"NMO\V``!`?^
MN00`3J?T]/G`Y?__XB('!P<'!P?K[_!P`"2G*0"`X_#_8/]QP.7__^!$P#%G
M12,!P`_OS:N)XS`@```DXP`@"``DP$^8NMS^P%$0,E1VXT`@$``DXU`@&``D
MP#_#TN'PY4@@*```XS`@(``DY4@@,```Y4P@>```Z^_Q$``$!_X'!P<'ZV_P
M,``DN00`[^/P_U#_<;D$`+*GZ__P8(#@`&"@X`BY!`"DXU`@*``$ZQ0``P`-
MXT`@,``$N0@`%>PD``$`V>P!(+\`5>,`L"@`)+DQ`%'K>@`=``RYXM`DN>@@
MA^.`L#``)+D$`&/CT+!X`!*G=`";07"P.*>N`#^GQ`""Z]H`!@#>[.T@N095
MI]K__^Q>_\``V4$>8`#KA0`&``RY%@!-IXL``;/!`(&SP0"DN00`ENP(/K\`
M5:>$`"ZG#P`!IX0`&J</``*GA``,09!@0+D$`"O2/W``8`#`Y?__\__2/W``
MD`"Y!``K09"00,#E___S]=(_<`"0`+D$`"M!D)!`P.7___/KL\T`*+D@`)*G
MA``IZX@``@`,TC]P`)``N00`*\#E___SVKD$`"O2/W``D$#`Y?__\]*Y!``K
MTC]P`)"`P.7___/*N00`*](_<`"0P$&0D0#`Y?__\\"GA__>IZK_P(G0``:S
MS0`Z&ZWKXP`&``VY%`"J06Y@0+D$`#:Y!``GN00`2L#E___B+U"@L'AH@/"@
M:*#PJ.MO\.``!`?^IY@`0!N=&9I!<+`XN?(PFKD$`">Y%`")N00`2+D8`"W`
MY?__XA(8.5HPL'A0,+!XISX`0*=T_]X;J;D(`&BY%`"JN00`*\#E___S=Z?T
M_T,'!P<'ZX_P0``DN00`L^.`,"@`!..0,#``!.P8.K\]5>/P_V#_<;D4`#%!
M0[`XDH!``*<:``&Y!`"BIQX`.+D4`"%!,K`XI\0`2Z=(`$"Y^1`D&4&GA``)
MIRK__[D6`!+&$````$ZY!``KP.7___,]US>P.+`XISD``.PY``=@5>PY"`]@
M5>PY$!=@5>PY&!\@5;D$`"OL@P`?`%7C@+!P`"3`Y?__\R&Y!``KT@*@`+`$
MT@"@`[`'T@.@!+`,T@.@"+`4T@.@#+`<T@.@$+`DZX_PX``$P/3__^#_IP@`
M.+GY$%`9`:>$_\BG6O__N18`Y<;@````"*?T_[_7`#``,`#7`#``,``'!P<'
MQ%@``#&<P/3__]ZA!P<'!^MO\#``).,0\'@`!*?[_V#C$/```"3`P```,'7C
M0/$0``3K;_#0``0']``````````"``$E<R\E<P`O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4```O<')O8R\E:2\E<P!E>&4`+@!005)?5$5-4```4$%27U!23T=.04U%
M```Z`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2
M`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M```Q`&QS965K(&9A:6QE9```<F5A9"!F86EL960`3$1?3$E"4D%265]0051(
M`%-94U1%30``)3`R>```)7,E<R5S)7,``'!A<BT``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S
M92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`
M`'!A<FP``"YP87(``'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,``!@`<&5R;```,`!005(Z.E!A
M8VME<CHZ5D524TE/3@``,2XP-C,`56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"UE```M+0``55-%4@``
M55-%4DY!344``%1%35!$25(`5$U0`"]T;7```&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*
M0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S
M971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`]
M(#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?
M<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S
M(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@
M(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI
M;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L
M("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E
M='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U
M<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@
M)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@
M)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN
M(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE
M)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D
M8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?
M1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@
M9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E
M(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O
M<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!
M4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]
M"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N
M92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD[
M"FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O
M=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@
M)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O
M;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A
M<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II
M9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U
M;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE
M86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D
M969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS
M965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H
M95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA
M;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F
M9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN
M9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!0
M05(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![
M(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O
M<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`[
M"FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S
M"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C
M86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M
M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M
M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*
M)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F
M:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT
M<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T
M96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH```!P97)L>'-I+F,``$-!0TA%```````````!&P,[````[````!S_
M_X(X```%Q/__A,````$(__^%N````3C__X:(```!B/__AQ@```&X__^(@```
M`?3__XL8```"-/__C`@```)P__^,@````JS__XRX```"P/__C9````+\__^-
MF````Q#__X_X```#3/__D#````-X__^1>````[S__Y=8```#\/__E^````0@
M__^86```!$S__YHP```$A/__FF````2D__^;4```!/3__Z'P```%1/__I#``
M``6`__^E"```!@C__[O````&2/__O#````9L__^^*```!K#__[\P```&Z```
M```````4``````%Z4@`!>`X!&PP/H`$'#@`````4````'/__@[````!"````
M```````````4``````%Z4@`!>`X!&PP/H`$```````!,````'/__A'@```#0
M`$R&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("C@K/SLW,R\K)R,?&#J`!0@M<
M"L_.S<S+RLG(Q\8.H`%""P```````"P```!L__^$^````(X`1HH*BPF,"(T'
MC@:/!48.V`,">@K/SLW,R\H.H`%""P```#@```"<__^%6````6(`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@[@`W0*S\[-S,O*R<C'Q@Z@`4(+`````#P```#8
M__^&A````I0`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[8`@,!6`K/SLW,R\K)
MR,?&#J`!0@L````````X```!&/__B-P```#P`$:'#8@,B0N*"HL)C`B-!XX&
MCP5&#L@B`I0*S\[-S,O*R<C'#J`!0@L````````X```!5/__B9````!T`%Z&
M#H<-B`R)"XH*BPF,"(T'C@:/!4P.R`("2,_.S<S+RLG(Q\8.H`$````````0
M```!D/__B<P````X`````````#@```&D__^)\````-0`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[80@*X"L_.S<S+RLG(Q\8.H`%""P```!````'@__^*C```
M``8`````````.````?3__XJ````"7`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#O`C`G8*S\[-S,O*R<C'Q@Z@`4(+````*````C#__XRD````-@!*BPF,"(T'
MC@:/!4H.P`)8S\[-S,L.H`$```````!````"7/__C+````%(`$:)"XH*BPF,
M"(T'C@:/!48.R"("Y`K/SLW,R\K)#J`!0@M<"L_.S<S+RLD.H`%&"P``````
M`#````*@__^-M```!=P`1HH*BPF,"(T'C@:/!48.T`(#!9P*S\[-S,O*#J`!
M1@L````````L```"U/__DV````""`$R+"8P(C0>.!H\%1@[0`@)@"L_.S<S+
M#J`!0@L````````H```#!/__D[@```!X`%J&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.Z`(``````#0```,P__^4!````=@`3H@,B0N*"HL)C`B-!XX&CP5&#M""
M!`,!F`K/SLW,R\K)R`Z@`4(+````'````VC__Y6D````+@!&C@:/!48.P`)@
MS\X.H`$```!,```#B/__E;0```#J`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.
MX`("4@K/SLW,R\K)R,?&#J`!1@L">@K/SLW,R\K)R,?&#J`!1@L``````$P`
M``/8__^65```!IP`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z0!0,">@K/SLW,
MR\K)R,?&#J`!0@L#`M(*S\[-S,O*R<C'Q@Z@`48+````.```!"C__YRD```"
M/`!&APV(#(D+B@J+"8P(C0>.!H\%4@[0`@,!O`K/SLW,R\K)R,<.H`%""P``
M````0```!&3__YZH````U@!&B0N*"HL)C`B-!XX&CP5&#M`"`F0*S\[-S,O*
MR0Z@`4(+`E@*S\[-S,O*R0Z@`48+``````!````$J/__?&P```*(`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.Z`(#`<0*S\[-S,O*R<C'Q@Z@`4(+````````
M`````#P```3L__^>^```%K(`3H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,6
MC@K/SLW,R\K)R,?&#J`!0@L````````@```%+/__M7````!L`$J.!H\%1@[`
M`@):S\X.H`$```````!````%4/__M;P```'T`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!4H.T`)0F!:9%0,!@@K/SLW,R\K)R,?&V=@.H`%""P```#0```64__^W
M<````00`1H@,B0N*"HL)C`B-!XX&CP5<#L`"`K`*S\[-S,O*R<@.H`%&"P``
M````$```!<S__[A`````#```````````````!````!`````!1TY5````````
M```#`````@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"-0````````(P@``````````0``
M``````+'``````````$````````"UP`````````,````````&-@`````````
M#0```````%S@`````````!D```````"[T``````````;``````````@`````
M````&@```````+O8`````````!P`````````"`````!O__[U`````````J@`
M````````!0````````PH``````````8````````#B``````````*````````
M!$<`````````"P`````````8`````````!4````````````````````#````
M````O>```````````@````````3X`````````!0`````````!P`````````7
M````````$^``````````!P```````!&(``````````@````````"6```````
M```)`````````!@`````````'@`````````(`````&____L`````"````0``
M``!O___^````````$2@`````;____P`````````!`````&____`````````0
M<`````!O___Y``````````X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````+O@`````````````````````````````!E&````````
M&68````````9A@```````!FF````````&<8````````9Y@```````!H&````
M````&B8````````:1@```````!IF````````&H8````````:I@```````!K&
M````````&N8````````;!@```````!LF````````&T8````````;9@``````
M`!N&````````&Z8````````;Q@```````!OF````````'`8````````<)@``
M`````!Q&````````'&8````````<A@```````!RF````````',8````````<
MY@```````!T&````````'28````````=1@```````!UF````````'88`````
M```=I@```````!W&````````'>8````````>!@```````!XF````````'D8`
M```````>9@```````!Z&````````'J8````````>Q@```````![F````````
M'P8````````?)@```````!]&````````'V8````````?A@```````!^F````
M````'\8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````']@``````````````````,`("E!!4BYP;0H`````````````
M`````&`0````````76P``````````````````%X,````````7A````````!@
M!````````%UR````````8`P``````````````````%_T````````7_H`````
M`````````````&`61T-#.B`H1&5B:6%N(#$T+C(N,"TQ-RD@,30N,BXP```N
M<VAS=')T86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M````````````````````````````````````````````````"P````<`````
M`````@````````)P`````````G``````````)`````````````````````0`
M`````````````!X````!``````````(````````"E`````````*4````````
M``\````````````````````!```````````````F;___]@`````````"````
M`````J@````````"J`````````#<````!```````````````"```````````
M````,`````L``````````@````````.(`````````X@````````(H`````4`
M```"``````````@`````````&````#@````#``````````(````````,*```
M``````PH````````!$<````````````````````!``````````````!`;___
M_P`````````"````````$'`````````0<`````````"X````!```````````
M`````@`````````"````36____X``````````@```````!$H````````$2@`
M````````8`````4````!``````````@``````````````%P````$````````
M``(````````1B````````!&(`````````E@````$```````````````(````
M`````!@```!F````!`````````!"````````$^`````````3X`````````3X
M````!````!4`````````"``````````8````<`````$`````````!@``````
M`!C8````````&-@`````````/@````````````````````0`````````````
M`&L````!``````````8````````9&````````!D8````````!L``````````
M```````````$`````````"````!V`````0`````````&````````']@`````
M```?V````````#T(````````````````````"```````````````?`````$`
M````````!@```````%S@````````7.``````````*@``````````````````
M``0``````````````((````!``````````(```````!=$````````%T0````
M````0)`````````````````````(``````````````"*`````0`````````"
M````````G:````````"=H`````````#L````````````````````!```````
M````````F`````$``````````@```````)Z0````````GI`````````&$```
M``````````````````@``````````````*(````'``````````(```````"D
MH````````*2@`````````"`````````````````````$``````````````"P
M````#@`````````#````````N]````````"KT``````````(````````````
M````````"``````````(````O`````\``````````P```````+O8````````
MJ]@`````````"`````````````````````@`````````"````,@````&````
M``````,```````"[X````````*O@`````````@`````%```````````````(
M`````````!````#1`````0`````````#````````O>````````"MX```````
M``(@````````````````````"``````````(````U@````$``````````P``
M`````,``````````L```````````B`````````````````````@`````````
M`````-P````(``````````,```````#`B````````+"(`````````"@`````
M```````````````(``````````````#A`````0`````````P````````````
M``````"PB``````````?`````````````````````0`````````!`````0``
M``,`````````````````````````````L*<`````````Z@``````````````
-``````$`````````````
